==> pentestkit-1.0.3.tgz: package/controller/rbuilder.js <==
/* Author: Denis Podgurskii */
import { ptk_exporter } from "../background/exporter.js"

export class ptk_controller_rbuilder {


    async reset() {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "reset"
        }).then(response => {
            return response
        })
    }


    async sendRequest(requestFormId, schema) {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "send_request",
            schema: schema,
            requestFormId: requestFormId
        }).then(response => {
            return response
        })
    }


    async parseRawRequest(item) {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "parse_request",
            item: item
        }).then(response => {
            return response
        })
    }

    async updateRawRequest(item) {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "update_request",
            item: JSON.parse(JSON.stringify(item))
        }).then(response => {
            return response
        })
    }

    async export() {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "get_recording"
        }).then(response => {
            let exporter = new ptk_exporter(response, { format: "har" })
            let output = exporter.render()
            return output
        })
    }

}

==> pentestkit-1.0.5.tgz: package/controller/rbuilder.js <==
/* Author: Denis Podgurskii */
import { ptk_exporter } from "../background/exporter.js"

export class ptk_controller_rbuilder {

    async init() {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "init"
        }).then(response => {
            return response
        })
    }

    async clear(index) {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "clear", 
            index: index
        }).then(response => {
            return response
        })
    }

    async resetAll() {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "reset_all"
        }).then(response => {
            return response
        })
    }


    async sendRequest(requestFormId, schema) {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "send_request",
            schema: schema,
            requestFormId: requestFormId
        }).then(response => {
            return response
        })
    }


    async parseRawRequest(item, formId) {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "parse_request",
            item: item, 
            formId: formId
        }).then(response => {
            return response
        })
    }

    async updateRawRequest(item, formId) {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "update_request",
            item: JSON.parse(JSON.stringify(item)),
            formId: formId
        }).then(response => {
            return response
        })
    }

    async deleteSavedRequest(formId) {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "delete_request",
            formId: formId
        }).then(response => {
            return response
        })
    }

    async export() {
        return browser.runtime.sendMessage({
            channel: "ptk_popup2background_request",
            type: "get_recording"
        }).then(response => {
            let exporter = new ptk_exporter(response, { format: "har" })
            let output = exporter.render()
            return output
        })
    }

}
